<?php

declare(strict_types=1);

namespace Drupal\slots\Plugin\Condition;

use Drupal\Core\Condition\ConditionPluginBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\slots\SlotIdMachineNameTrait;

/**
 * Provides a 'Slot' condition.
 *
 * @Condition(
 *   id = "slot",
 *   label = @Translation("Slot"),
 *   description = @Translation("The slot id."),
 *   context_definitions = {
 *     "slot_id" = @ContextDefinition("slot", label = @Translation("The slot id"))
 *   }
 * )
 */
class SlotCondition extends ConditionPluginBase {

  use SlotIdMachineNameTrait;

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return array_merge(parent::defaultConfiguration(), [
      'slot_id' => '',
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['slot_id'] = [
      '#type' => 'machine_name',
      '#machine_name' => [
        'exists' => [$this, 'slotIdExistsCallback'],
        'replace_pattern' => $this->getReplacePattern(),
      ],
      '#title' => $this->t('Slot identifier'),
      '#default_value' => $this->configuration['slot_id'],
    ];

    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['slot_id'] = $form_state->getValue('slot_id');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function summary() {
    if (!empty($this->configuration['negate'])) {
      return $this->t('Do not apply for slots with the id: %id', ['%id' => $this->configuration['slot_id']]);
    }

    return $this->t('Apply for slots with the id: %id', ['%id' => $this->configuration['slot_id']]);
  }

  /**
   * {@inheritdoc}
   */
  public function evaluate() {
    $slot_id = $this->getContext('slot_id')->getContextValue();
    if (!empty($this->configuration['negate'])) {
      return $this->configuration['slot_id'] !== $slot_id;
    }

    return $this->configuration['slot_id'] === $slot_id;
  }

}
